@@ -15,6 +15,8 @@
 #' located, an informative error is generated.
 #' @param workers The maximum number of multicore futures that can
 #' be active at the same time before blocking.
+#' @param gc If TRUE, the garbage collector run after the future
+#' is resolved (in the process that evaluated the future).
 #' @param earlySignal Specified whether conditions should be signaled as soon as possible or not.
 #' @param \dots Not used.
 #'
@@ -59,7 +61,7 @@
 #' system.
 #'
 #' @export
-multicore <- function(expr, envir=parent.frame(), substitute=TRUE, globals=TRUE, workers=availableCores(constraints="multicore"), earlySignal=FALSE, ...) {
+multicore <- function(expr, envir=parent.frame(), substitute=TRUE, globals=TRUE, workers=availableCores(constraints="multicore"), gc=FALSE, earlySignal=FALSE, ...) {
   ## BACKWARD COMPATIBILITY
   args <- list(...)
   if ("maxCores" %in% names(args)) {
@@ -75,9 +77,9 @@ multicore <- function(expr, envir=parent.frame(), substitute=TRUE, globals=TRUE,
   ## Fall back to eager futures if only a single additional R process
   ## can be spawned off, i.e. then use the current main R process.
   ## Eager futures best reflect how multicore futures handle globals.
-  if (workers == 1L || availableCores(constraints="multicore") == 1L) {
+  if (workers == 1L || !supportsMulticore()) {
     ## covr: skip=1
-    return(eager(expr, envir=envir, substitute=FALSE, globals=globals, local=TRUE))
+    return(eager(expr, envir=envir, substitute=FALSE, globals=globals, local=TRUE, gc=gc))
   }
 
   ## Validate globals at this point in time?
@@ -88,7 +90,7 @@ multicore <- function(expr, envir=parent.frame(), substitute=TRUE, globals=TRUE,
   oopts <- options(mc.cores=workers)
   on.exit(options(oopts))
 
-  future <- MulticoreFuture(expr=expr, envir=envir, substitute=FALSE, earlySignal=earlySignal)
+  future <- MulticoreFuture(expr=expr, envir=envir, substitute=FALSE, workers=workers, gc=gc, earlySignal=earlySignal)
   run(future)
 }
 class(multicore) <- c("multicore", "multiprocess", "future", "function")
@@ -148,6 +150,7 @@ usedCores <- function() {
 #'
 #' @param await A function used to try to "collect"
 #'        finished multicore subprocesses.
+#' @param workers Total number of workers available.
 #' @param maxTries Then maximum number of times subprocesses
 #'        should be collected before timeout.
 #' @param delta Then base interval (in seconds) to wait
@@ -159,17 +162,17 @@ usedCores <- function() {
 #'         extensive waiting, then a timeout error is thrown.
 #'
 #' @keywords internal
-requestCore <- function(await, maxTries=getOption("future.maxTries", trim(Sys.getenv("R_FUTURE_MAXTRIES", 1000))), delta=getOption("future.interval", 1.0), alpha=getOption("future.alpha", 1.01)) {
+requestCore <- function(await, workers=availableCores(), maxTries=getOption("future.maxTries", trim(Sys.getenv("R_FUTURE_MAXTRIES", 1000))), delta=getOption("future.interval", 1.0), alpha=getOption("future.alpha", 1.01)) {
+  stopifnot(length(workers) == 1L, is.numeric(workers), is.finite(workers), workers >= 1)
   stopifnot(is.function(await))
   maxTries <- as.integer(maxTries)
   stopifnot(is.finite(maxTries), maxTries > 0)
   stopifnot(is.finite(alpha), alpha > 0)
 
-  ## Maximum number of cores available
-  total <- availableCores()
+  mdebug(sprintf("requestCore(): workers = %d", workers))
 
   ## No additional cores available?
-  if (total == 1L) {
+  if (workers == 1L) {
     stop("INTERNAL ERROR: requestCore() was asked to find a free core, but there is only one core available, which is already occupied by the main R process.")
   }
 
@@ -177,9 +180,12 @@ requestCore <- function(await, maxTries=getOption("future.maxTries", trim(Sys.ge
   interval <- delta
   finished <- FALSE
   while (tries <= maxTries) {
-    finished <- (usedCores() < total)
+    used <- usedCores()
+    finished <- (used < workers)
     if (finished) break
 
+    mdebug(sprintf("usedCores() = %d, workers = %d", used, workers))
+
     ## Wait
     Sys.sleep(interval)
 
@@ -191,7 +197,7 @@ requestCore <- function(await, maxTries=getOption("future.maxTries", trim(Sys.ge
   }
 
   if (!finished) {
-    msg <- sprintf("TIMEOUT: All %d CPU cores are still occupied", total)
+    msg <- sprintf("TIMEOUT: All %d CPU cores are still occupied", workers)
     mdebug(msg)
     stop(msg)
   }
