@@ -7,7 +7,7 @@
 #' object is kept.
 #'
 #' @param x An environment, a list, or a list environment.
-#' @param ... Not used.
+#' @param ... Additional arguments passed to \code{value()} of each future.
 #'
 #' @return An object of same type as \code{x} and with the same names
 #' and/or dimensions, if set.
@@ -22,7 +22,7 @@ values.list <- function(x, ...) {
 
   for (ii in seq_along(y)) {
     tmp <- y[[ii]]
-    if (inherits(tmp, "Future")) y[[ii]] <- value(tmp)
+    if (inherits(tmp, "Future")) y[[ii]] <- value(tmp, ...)
   }
   y
 }
@@ -34,7 +34,7 @@ values.environment <- function(x, ...) {
   names <- ls(envir=y, all.names=TRUE)
   for (key in names) {
     tmp <- y[[key]]
-    if (inherits(tmp, "Future")) y[[key]] <- value(tmp)
+    if (inherits(tmp, "Future")) y[[key]] <- value(tmp, ...)
   }
   y
 }
@@ -45,7 +45,7 @@ values.listenv <- function(x, ...) {
   y <- resolve(y)
   for (ii in seq_along(y)) {
     tmp <- y[[ii]]
-    if (inherits(tmp, "Future")) y[[ii]] <- value(tmp)
+    if (inherits(tmp, "Future")) y[[ii]] <- value(tmp, ...)
   }
   y
 }
