@@ -9,12 +9,12 @@ import io
 import functools
 from textwrap import dedent
 
-if not hasattr(unittest, 'skip'):
-    import unittest2 as unittest
-
-from future.utils import bind_method, PY26, PY3, PY2
+from future.utils import bind_method, PY26, PY3, PY2, PY27
 from future.moves.subprocess import check_output, STDOUT, CalledProcessError
 
+if PY26:
+    import unittest2 as unittest
+
 
 def reformat_code(code):
     """
@@ -44,7 +44,8 @@ def order_future_lines(code):
                                if line.startswith('from __future__ import ')]
 
     future_line_numbers = [i for i, line in enumerate(lines)
-                             if line.startswith('from future')]
+                             if line.startswith('from future')
+                             or line.startswith('from past')]
 
     builtins_line_numbers = [i for i, line in enumerate(lines)
                              if line.startswith('from builtins')]
@@ -56,7 +57,7 @@ def order_future_lines(code):
         return max(numbers) if len(numbers) > 0 else 0
 
     def mymin(numbers):
-        return min(numbers) if len(numbers) > 0 else 0
+        return min(numbers) if len(numbers) > 0 else float('inf')
 
     assert mymax(uufuture_line_numbers) <= mymin(future_line_numbers), \
             'the __future__ and future imports are out of order'
@@ -152,7 +153,11 @@ class CodeHandler(unittest.TestCase):
         """)
         self.interpreters = [sys.executable]
         self.tempdir = tempfile.mkdtemp() + os.path.sep
-        self.env = {'PYTHONPATH': os.getcwd()}
+        pypath = os.getenv('PYTHONPATH')
+        if pypath:
+            self.env = {'PYTHONPATH': os.getcwd() + os.pathsep + pypath}
+        else:
+            self.env = {'PYTHONPATH': os.getcwd()}
 
     def convert(self, code, stages=(1, 2), all_imports=False, from3=False,
                 reformat=True, run=True, conservative=False):
@@ -321,13 +326,18 @@ class CodeHandler(unittest.TestCase):
         try:
             output = check_output(call_args, stderr=STDOUT, env=self.env)
         except CalledProcessError as e:
-            msg = ('Error running the command %s\n%s\nContents of file %s:\n\n%s' %
-                   (' '.join(call_args),
-                    'env=%s' % self.env,
-                    fn,
-                    '----\n%s\n----' % open(fn).read(),
-                   )
-                  )
+            with open(fn) as f:
+                msg = (
+                    'Error running the command %s\n'
+                    '%s\n'
+                    'Contents of file %s:\n'
+                    '\n'
+                    '%s') % (
+                        ' '.join(call_args),
+                        'env=%s' % self.env,
+                        fn,
+                        '----\n%s\n----' % f.read(),
+                    )
             ErrorClass = (FuturizeError if 'futurize' in script else PasteurizeError)
             raise ErrorClass(msg, e.returncode, e.cmd, output=e.output)
         return output
@@ -340,13 +350,18 @@ class CodeHandler(unittest.TestCase):
             output = check_output([interpreter, fn],
                                   env=self.env, stderr=STDOUT)
         except CalledProcessError as e:
-            msg = ('Error running the command %s\n%s\nContents of file %s:\n\n%s' %
-                   (' '.join([interpreter, fn]),
-                    'env=%s' % self.env,
-                    fn,
-                    '----\n%s\n----' % open(fn).read(),
-                   )
-                  )
+            with open(fn) as f:
+                msg = (
+                    'Error running the command %s\n'
+                    '%s\n'
+                    'Contents of file %s:\n'
+                    '\n'
+                    '%s') % (
+                        ' '.join([interpreter, fn]),
+                        'env=%s' % self.env,
+                        fn,
+                        '----\n%s\n----' % f.read(),
+                    )
             raise VerboseCalledProcessError(msg, e.returncode, e.cmd, output=e.output)
         return output
 
@@ -364,29 +379,19 @@ def expectedFailurePY3(func):
 def expectedFailurePY26(func):
     if not PY26:
         return func
-    @functools.wraps(func)
-    def wrapper(*args, **kwargs):
-        try:
-            func(*args, **kwargs)
-        except Exception:
-            raise unittest.case._ExpectedFailure(sys.exc_info())
-        # The following contributes to a FAILURE on Py2.6 (with
-        # unittest2). Ignore it ...
-        # raise unittest.case._UnexpectedSuccess
-    return wrapper
+    return unittest.expectedFailure(func)
+
+
+def expectedFailurePY27(func):
+    if not PY27:
+        return func
+    return unittest.expectedFailure(func)
 
 
 def expectedFailurePY2(func):
     if not PY2:
         return func
-    @functools.wraps(func)
-    def wrapper(*args, **kwargs):
-        try:
-            func(*args, **kwargs)
-        except Exception:
-            raise unittest.case._ExpectedFailure(sys.exc_info())
-        raise unittest.case._UnexpectedSuccess
-    return wrapper
+    return unittest.expectedFailure(func)
 
 
 # Renamed in Py3.3:
