@@ -30,5 +30,12 @@ Sys.setenv("FOO_BAR_ENV"="0")
 res <- try(availableCores(methods="FOO_BAR_ENV"), silent=TRUE)
 stopifnot(inherits(res, "try-error"))
 
+
+## Deprecated
+res <- tryCatch(availableCores(methods="mc.cores"), warning=function(w) w)
+print(res)
+stopifnot(inherits(res, "warning"))
+
+
 message("*** availableCores() ... DONE")
 
