@@ -15,6 +15,17 @@ y <- value(f)
 print(y)
 stopifnot(y == 42L)
 
+
+message("*** future() w/ gc=TRUE ...")
+
+f <- future(42L, gc=TRUE)
+print(f)
+y <- value(f)
+print(y)
+stopifnot(y == 42L)
+
+message("*** future() w/ gc=TRUE ... DONE")
+
 message("*** future() ... DONE")
 
 ## Cleanup
