@@ -6,7 +6,7 @@ oopts <- options(warn=1)
 plan(lazy)
 
 
-message("*** %<=% to listenv ...")
+message("*** %<-% to listenv ...")
 
 ## - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 ## Future assignment via infix operator
@@ -14,26 +14,26 @@ message("*** %<=% to listenv ...")
 z <- listenv()
 stopifnot(length(names(z)) == 0)
 
-message("*** %<=% to listenv: Assign by index")
-z[[1]] %<=% { 2 }
+message("*** %<-% to listenv: Assign by index")
+z[[1]] %<-% { 2 }
 stopifnot(length(z) == 1)
 stopifnot(length(names(z)) == 0)
 
-z[[1]] %<=% { 2 }
+z[[1]] %<-% { 2 }
 stopifnot(length(z) == 1)
 stopifnot(length(names(z)) == 0)
 
-z[[4]] %<=% { "async!" }
+z[[4]] %<-% { "async!" }
 stopifnot(length(z) == 4)
 stopifnot(length(names(z)) == 0)
 
-message("*** %<=% to listenv: Update names")
+message("*** %<-% to listenv: Update names")
 names(z) <- c("A", "B", "C", "D")
 stopifnot(identical(names(z), c("A", "B", "C", "D")))
 
 
-message("*** %<=% to listenv: Assign by name (existing)")
-z$B %<=% TRUE
+message("*** %<-% to listenv: Assign by name (existing)")
+z$B %<-% TRUE
 stopifnot(length(z) == 4)
 stopifnot(identical(names(z), c("A", "B", "C", "D")))
 
@@ -43,14 +43,14 @@ stopifnot(length(y) == 4)
 stopifnot(identical(names(y), c("A", "B", "C", "D")))
 
 
-message("*** %<=% to listenv: Asserting no name clashes among futures")
+message("*** %<-% to listenv: Asserting no name clashes among futures")
 u <- listenv()
-u$a %<=% 1
+u$a %<-% 1
 stopifnot(identical(names(u), "a"))
 fu <- futureOf(u$a)
 
 v <- listenv()
-v$a %<=% 2
+v$a %<-% 2
 stopifnot(identical(names(v), "a"))
 fv <- futureOf(v$a)
 stopifnot(!identical(fu, fv))
@@ -62,7 +62,7 @@ stopifnot(identical(u$a, 1))
 stopifnot(identical(v$a, 2))
 
 
-message("*** %<=% to listenv: multiple dimensions ...")
+message("*** %<-% to listenv: multiple dimensions ...")
 
 x0 <- list()
 length(x0) <- 6
@@ -75,7 +75,7 @@ dim(x) <- c(3,2)
 for (cc in 1:ncol(x)) {
   for (rr in 1:nrow(x)) {
     x0[[rr,cc]] <- sprintf("(%s,%s)", rr, cc)
-    x[[rr,cc]] %<=% sprintf("(%s,%s)", rr, cc)
+    x[[rr,cc]] %<-% sprintf("(%s,%s)", rr, cc)
   }
 }
 
@@ -83,9 +83,9 @@ y <- as.list(x)
 dim(y) <- dim(x)
 stopifnot(identical(y, x0))
 
-message("*** %<=% to listenv: multiple dimensions ... DONE")
+message("*** %<-% to listenv: multiple dimensions ... DONE")
 
-message("*** %<=% to listenv ... DONE")
+message("*** %<-% to listenv ... DONE")
 
 
 ## Cleanup
