@@ -8,7 +8,7 @@ setTimeLimit(cpu=10, elapsed=10, transient=TRUE)
 message("*** Tricky use cases related to globals (part 2) ...")
 
 ## Allow for two (sic!) background processes
-plan(multisession, maxCores=3L)
+plan(multisession, workers=3L)
 
 env <- new.env()
 
